/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _BALL_H
#define _BALL_H

#include "common.h"
#include "display.h"
#include "player.h"
#include "status_bar.h"

/*!
 * \brief Representa la pelota del partido de volleyball (escena Game)
 * 
 * 
 * La pelota tiene una animacin de giro muy sencilla, el atributo `image` 
 * contiene una grilla con varios grficos de la pelota con diferentes grados
 * de inclinacin. En cada actualizacin lgica (ver `ball_update`) se invoca 
 * a la funcin `ball_animation_update` que altera la velocidad de 
 * animacin conforme a la componente horizontal de velocidad `vx`, esto
 * produce la sensacin de giro y velocidad.
 */
typedef struct ball
{
	float x;		/*!< posicin horizontal (centro de la pelota)*/
	float y;		/*!< posicin vertical (centro de la pelota) */
	float step;		/*!< cuadro de animacin actual */
	float vx;		/*!< velocidad actual, componente horizontal */
	float vy;		/*!< velocidad actual, componente vertical */
	int delay;		/*!< contador general */ 
	float angle;		/*!< ngulo de giro para el estado `restart` */
	int final_x;		/*!< destino de la pelota cuando inicia */
	int final_y;		/*!< destino de la pelota cuando inicia */
	int collision;		/*!< contador que indica si la pelota 
				  colision recientemente (collision > 0), ver 
				  estado `bouncing` */
	int ratio;		/*!< radio de la pelota */
	float power;		/*!< fuerza de la pelota */
	int player_start;	/*!< jugador que realiz el ltimo `saque` */

	SDL_Surface * image;		/*!< cuadros de animacin */
	SDL_Surface * collision_image;	/*!< cuadros de animacin en colision */
	
	void (* state) (struct ball * data);	/*!< funcin gestor de estado */

	Player * player_1;
	Player * player_2;
	Status_bar * status_bar;
} Ball;


Ball * ball_init (int pos, Player * p1, Player * p2, Status_bar * status_bar, 
		int debug);
void ball_update (Ball * data);
void ball_draw (Ball * data, Display * display);
void ball_animation_update (Ball * data);
void ball_free (Ball * data);

void ball_init_bouncing (Ball * data);
void ball_init_restart (Ball * data);
void ball_init_ready (Ball * data);
void ball_init_goal (Ball * data);

void ball_state_bouncing (Ball * data);
void ball_state_restart (Ball * data);
void ball_state_ready (Ball * data);
void ball_state_goal (Ball * data);

void ball_change_state (Ball * data, void (* init) (Ball * data), 
		void (* update) (Ball * data));
void ball_draw_debug_lines (Ball * data);
int ball_collision (Ball * data);
int ball_check_boundary_collision (Ball * data);
void ball_separate (Ball * data, int px, int py, int pratio);

#endif
