/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "item.h"
#include "common.h"

/*!
 * \brief Genera un nuevo mdulo item
 * \param title titulo de la opcin
 * \param x posicin horizontal
 * \param y posicin vertical
 * \param font mdulo de fuentes
 * \param display mdulo utilizado para imprimir grficos
 * \return el mdulo creado
 */
Item * item_new (char * title, int x, int y, Font * font, Display * display)
{
	Item * data;

	data = (Item *) malloc (sizeof (Item));

	if (!data)
	{
		util_print_fail_module ("Item");
		exit (1);
	}

	strcpy (data->title, title);
	data->x = x;
	data->y = y;
	data->font = font;
	data->display = display;
	data->type = TYPE_NORMAL;

	return data;
}

/*!
 * \brief imprime la opcin en pantalla
 * \param data mdulo principal
 */
void item_draw (Item * data)
{
	font_printf (data->font, data->display, data->x, data->y, data->type, 
			data->title);
}

/*!
 * \brief selecciona un item del men
 * \param data mdulo principal
 */
void item_enter (Item * data)
{
	data->type = TYPE_SELECTED;
}

/*!
 * \brief quita la seleccin de un item de men
 * \param data mdulo principal
 */
void item_leave (Item * data)
{
	data->type = TYPE_NORMAL;
}


/*!
 * \brief Deshabilita el ttulo de la opcin
 * \param data mdulo principal
 */
void item_disable (Item * data)
{
	data->type = TYPE_DISABLED;
}

/*!
 * \brief Habilita el ttulo del men
 * \param data mdulo principal
 */
void item_enable (Item * data)
{
	data->type = TYPE_NORMAL;
}


/*!
 * \brief informa si se puede seleccionar el ttulo de la opcin
 * \param data mdulo principal
 */
int item_is_enabled (Item * data)
{
	return (data->type != TYPE_DISABLED);
}

/*!
 * \brief informa la posicin vertical del item
 * \param mdulo principal
 * \return posicin vertical
 */
int item_get_y (Item * data)
{
	return data->y;
}

/*!
 * \brief elimina el mdulo
 * \param data mdulo principal
 */
void item_free (void * data)
{
	Item * tmp;

	tmp = (Item *) data;
	free (tmp);
}
