/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "option_menu.h"
#include "main_menu.h"


/*!
 * \brief Inicia el men de opciones, en caso de error termina el programa
 * \param world mdulo principal de todo el programa
 * \return el mdulo Option_menu creado
 */
Option_menu * option_menu_init (World * world)
{
	Option_menu * data;
	
	data = (Option_menu *) malloc (sizeof (Option_menu));

	if (! data)
	{
		util_print_fail_module ("Option_menu");
		exit (1);
	}

	data->world = world;
	data->menu = menu_init (world);

	menu_add_item (data->menu, _("Set Fullscreen mode"));
	menu_add_item (data->menu, _("Set Window mode"));
	menu_add_item (data->menu, _("Return"));

	option_menu_draw_background (data);

	return data;
}


/*!
 * \brief Pinta el fondo de pantalla
 * \param data mdulo principal
 */
void option_menu_draw_background (Option_menu * data)
{
	SDL_Surface * background;

	background = util_load_image (DATADIR "/main_menu.png", FALSE);

	if (background)
	{
		display_set_background (data->world->display, background);
		SDL_FreeSurface (background);
	}
}


/*!
 * \brief Actualizacin lgica
 * \param data mdulo principal
 */
void option_menu_update (Option_menu * data)
{
	int option;

	option = menu_update (data->menu);

	switch (option)
	{
		case 0:
			display_enable_fullscreen (data->world->display);
			break;

		case 1:
			display_disable_fullscreen (data->world->display);
			break;

		case 2:
			option_exit (data);
			break;

		default:
			break;
	}

	if (control_query (data->world->control, QUIT))
		option_exit (data);


	
}

/*!
 * \brief Regresa al men principal del juego
 * \param data mdulo principal
 */
void option_exit (Option_menu * data)
{
	Main_menu * menu;

	menu = main_menu_init (data->world);
	
	world_change_scene (data->world, menu, main_menu_update, 
			main_menu_draw, main_menu_free);
}

/*!
 * \brief Actualizacin grfica
 * \param data mdulo principal
 */ 
void option_menu_draw (Option_menu * data)
{
	font_printf (data->world->font, data->world->display, 10, 10, 0, 
			_("Options"));

	menu_draw (data->menu);
}

/*!
 * \brief Elimina el mdulo
 * \param data mdulo principal
 */ 
void option_menu_free (Option_menu * data)
{
	menu_free (data->menu);
}
